pub struct ProtoHttp2MakeLayer<SERVICE>{ /* private fields */ }Expand description
This is the initializer for the layer. Invocations to the service will take the sender and receiver of the connection and process the full lifetime.
Implementations